@@ -21,8 +21,8 @@
 	    }
 	    va_end(ap);
 	}
-	int main(int argc, char *argv[])
+	int main(void)
 	{
-	    test(test, 1, 2, 3, 4, 5, 6, 7, 8, 9);
+	    test("test", 1, 2, 3, 4, 5, 6, 7, 8, 9);
 	    exit(0);
 	}
